<?php
/**
 * Plugin Name:       AbcSubmit
 * Description:       Build powerful forms for your website, create online shop, collect data and files, accept payments online, create sliders for your page.
 * Version:           1.1.0
 * Author:            AbcSubmit
 * Author URI:        https://www.abcsubmit.com
 * License:           GPL-2.0+
 * Text Domain:       abcsubmit
 */

defined( 'ABSPATH' ) or die("You can not access this file!");

if ( ! function_exists( 'add_action' ) ) {
    die("You can not access this file!");
}

/*
 * Main class
 */
/**
 * Class AbcSubmit
 *
 * This class creates the option page and add the web app script
 */
class AbcSubmit
{
    const ABCSUBMIT_WP_DOMAIN = '//wordpress.abcsubmit.com';
    /**
     * Plugin version
     *
     * @var string
     */
    private $pluginVersion;

	/**
	 * AbcSubmit constructor.
     *
     * The main plugin actions registered for WordPress
	 */



	public function __construct()
    {

        $this->pluginName = 'abcsubmit';
        $this->pluginVersion = '1.1.0';

        if (
            (
                in_array($this->pluginName . '/' . $this->pluginName . '.php', get_option('active_plugins'))
                || (
                    function_exists('is_plugin_active_for_network')
                    && is_plugin_active_for_network($this->pluginName . '/' . $this->pluginName . '.php')
                )
            )
        && strstr($_SERVER['REQUEST_URI'], 'wp-admin/post-new.php') || strstr($_SERVER['REQUEST_URI'], 'wp-admin/post.php')
        ) {

            add_action('media_buttons', array($this, 'addMediaButtonInWPEditor'));
            add_filter('wp_enqueue_media', array($this, 'addMediaScriptsInWPEditor'));
        }

        if (in_array($this->pluginName . '/' . $this->pluginName . '.php', get_option('active_plugins'))
            || (
                function_exists('is_plugin_active_for_network')
                && is_plugin_active_for_network($this->pluginName . '/' . $this->pluginName . '.php')
            )
        ){
            wp_enqueue_script('thickbox', null, array('jquery'));
            wp_enqueue_style('thickbox');
        }

        add_shortcode( 'abc-submit-inline', array($this,'replaceShortCodeWithEmbedCodeJs'));
        add_shortcode( 'abc-submit-popup', array($this,'replaceShortCodeWithButton'));

        wp_enqueue_style('admin_abcsubmit_css', plugin_dir_url( __FILE__ ) . '/assets/css/admin.css', array(), $this->pluginVersion);

        add_filter( 'widget_text', 'do_shortcode' );
        add_filter( 'the_content', 'do_shortcode' );
        add_filter('comment_text', 'do_shortcode');
        add_filter('get_comment_text', 'do_shortcode');
        add_filter('the_excerpt', 'do_shortcode');

        add_action('admin_menu', array($this,'addAdminMenu'));

	}

    function replaceShortCodeWithButton( $atts ) {

        $resultAtts = shortcode_atts( array(
            'id' => '0',
            'name' => 'Click to Open'
        ), $atts );

        $documentId = esc_attr($resultAtts['id']);
        $documentName = esc_attr($resultAtts['name']);

        return
            '<a 
                    style="padding: 4px 10px 4px 10px;background-color: #25a725;color: white;border-radius: 4px;"
                    class="thickbox abcsubmit-document-button abcsubmit-document-'. $documentId . '" 
                    href="//www.abcsubmit.com/view/' . $documentId . '?KeepThis=true&TB_iframe=true&height=400&width=600">' .
                    $documentName .
            '</a>';
    }

    function replaceShortCodeWithEmbedCodeJs($atts) {

        $resultAtts = shortcode_atts( array(
            'id' => '0'
        ), $atts );

        $id = esc_attr($resultAtts['id']);

        return '<script type="text/javascript" src="/embed/' .
            $id .
            '/embed-form.js" data-role="abcsubmit-form-embed" data-document-id="' .
            $id .
            '" ></script>';
    }

    function addMediaButtonInWPEditor() {
        ?>
        <a id="abcsubmit-media-button" class="button" onclick="showWPThickboxWithOurDocuments()">
            <img class="abcsubmit-media-logo-image" src="<?=plugin_dir_url(plugin_dir_path(__FILE__))?><?php echo $this->pluginName ?>/assets/img/iconAbcSubmit.png"> AbcSubmit
        </a>

        <div id="abcsubmit-media-thickbox" style="display:none"></div>
        <?php
    }

	/**
	 * Create menu and submenu
	 */
	public function addAdminMenu()
    {
        if ( ! current_user_can('manage_options' ) ) {
            return;
        }

		add_menu_page(
            $this->pluginName,
			'AbcSubmit',
			'manage_options',
            $this->pluginName,
			array($this, 'addAbcSubmitEditor'),
			'dashicons-forms',
            2
		);

        add_submenu_page(
            $this->pluginName,
            'AbcSubmit',
            'Builder',
            'manage_options',
            $this->pluginName,
            array($this, 'addAbcSubmitEditor')
        );

        add_submenu_page(
            $this->pluginName,
            'AbcSubmit',
            'Form Templates',
            'manage_options',
            'abcSubmitFormTemplates',
            array($this, 'addAbcSubmitSubMenuFormTemplates')
        );

        add_submenu_page(
            $this->pluginName,
            'AbcSubmit',
            'Website Templates',
            'manage_options',
            'abcSubmitWebsiteTemplates',
            array($this, 'addAbcSubmitSubMenuWebsiteTemplates')
        );

	}

	public function addAbcSubmitEditor()
    {
        echo ' <iframe 
                    class="abcsubmit-content-preview"
                    src="'.self::ABCSUBMIT_WP_DOMAIN.'/edit/" 
                    frameborder="0"
                >';
	}

    public function addAbcSubmitSubMenuFormTemplates()
    {
        echo ' <iframe 
                    class="abcsubmit-content-preview"
                    src="'.self::ABCSUBMIT_WP_DOMAIN.'/site/free-form-templates/?scrollbars=0"
                    scrolling="no" 
                    frameborder="0"
                >';
    }

    public function addAbcSubmitSubMenuWebsiteTemplates()
    {
        echo ' <iframe 
                    class="abcsubmit-content-preview"
                    src="'.self::ABCSUBMIT_WP_DOMAIN.'/site/free-website-templates/?scrollbars=0"
                    scrolling="no" 
                    frameborder="0"
                >';
    }

    function addMediaScriptsInWPEditor()
    {
        wp_enqueue_style('media_button_css', plugin_dir_url( __FILE__ ) . '/assets/css/widget.css', array(), $this->pluginVersion);
        wp_enqueue_script('media_button_js', plugin_dir_url( __FILE__ ) . '/assets/js/widget.js', array(), $this->pluginVersion);
    }

}

if ( class_exists('AbcSubmit') ) {
    $abcsubmitDocuments = new AbcSubmit();
}


